@@ -27,8 +27,7 @@
 #include <QClipboard>
 #include <QTimer>
 #include <QMap>
-#include <QMetaEnum>
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include <QDebug>
 
@@ -61,7 +60,7 @@ public:
     }
 };
 
-class BrowserExtension::BrowserExtensionPrivate
+class Q_DECL_HIDDEN BrowserExtension::BrowserExtensionPrivate
 {
 public:
     BrowserExtensionPrivate(KParts::ReadOnlyPart *parent)
@@ -175,7 +174,7 @@ int BrowserExtension::yOffset()
 void BrowserExtension::saveState(QDataStream &stream)
 {
     // TODO add d->m_part->mimeType()
-    stream << d->m_part->url() << (qint32)xOffset() << (qint32)yOffset();
+    stream << d->m_part->url() << static_cast<qint32>(xOffset()) << static_cast<qint32>(yOffset());
 }
 
 void BrowserExtension::restoreState(QDataStream &stream)
@@ -213,7 +212,7 @@ void BrowserExtension::pasteRequest()
     QString plain(QStringLiteral("plain"));
     QString url = QApplication::clipboard()->text(plain, QClipboard::Selection).trimmed();
     // Remove linefeeds and any whitespace surrounding it.
-    url.remove(QRegExp(QStringLiteral("[\\ ]*\\n+[\\ ]*")));
+    url.remove(QRegularExpression(QStringLiteral("[\\ ]*\\n+[\\ ]*")));
 
     // Check if it's a URL
     QStringList filters = KUriFilter::self()->pluginNames();
@@ -254,7 +253,7 @@ void BrowserExtension::slotOpenUrlRequest(const QUrl &url, const KParts::OpenUrl
     req.m_delayedArgs = args;
     req.m_delayedBrowserArgs = browserArgs;
     d->m_requests.append(req);
-    QTimer::singleShot(0, this, SLOT(slotEmitOpenUrlRequestDelayed()));
+    QTimer::singleShot(0, this, &BrowserExtension::slotEmitOpenUrlRequestDelayed);
 }
 
 void BrowserExtension::slotEmitOpenUrlRequestDelayed()
