@@ -32,7 +32,9 @@ namespace KParts
 class BrowserOpenOrSaveQuestionPrivate;
 
 /**
- * This class shows the dialog that asks the user whether to
+ * @class BrowserOpenOrSaveQuestion browseropenorsavequestion.h <KParts/BrowserOpenOrSaveQuestion>
+ *
+ * @short This class shows the dialog that asks the user whether to
  * save a url or open a url in another application.
  *
  * It also has the variant which asks "save or embed" (e.g. into konqueror).
@@ -80,15 +82,22 @@ public:
      */
     Result askOpenOrSave();
 
+    /**
+     * @since 5.65
+     */
+    enum AskEmbedOrSaveFlags {
+        InlineDisposition = 0,
+        AttachmentDisposition = 1,
+    };
+
     /**
      * Ask the user whether to save or open a url in another application.
-     * @param flags set to BrowserRun::AttachmentDisposition if suggested by the server
+     * @param flags set to AttachmentDisposition if suggested by the server
      * This is used because by default text/html files are opened embedded in browsers, not saved.
      * But if the server said "attachment", it means the user is download a file for saving it.
      * @return Save, Embed or Cancel.
      */
     Result askEmbedOrSave(int flags = 0);
-    // KDE5 TODO: move BrowserRun::AskEmbedOrSaveFlags to this class.
 
     // TODO askOpenEmbedOrSave
 
